Kultaviulu by Ferenc Herczeg | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# Kultaviulu by Ferenc Herczeg

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/75224.html.images | 422 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/75224.epub3.images | 219 kB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/75224.epub.noimages | 223 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/75224.kf8.images | 408 kB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/75224.kindle.images | 379 kB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/75224.txt.utf-8 | 367 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/75224/pg75224-h.zip | 216 kB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…

## About this eBook

Author | Herczeg, Ferenc, 1863-1954
Translator | Pesola, Väinö
Title | Kultaviulu
Original Publication | Helsinki: Kust.Oy Ahjo, 1919.
Credits | Tuula Temonen and Tapio Riikonen
Language | Finnish
Category | Text
EBook-No. | 75224
Release Date | Jan 27, 2025
Copyright Status | Public domain in the USA.
Downloads | 0 downloads in the last 30 days.
Project Gutenberg eBooks are always free!